AppLocalizations class abstract

Callers can lookup localized strings with an instance of AppLocalizations returned by AppLocalizations.of(context).

Applications need to include AppLocalizations.delegate() in their app's localizationDelegates list, and the locales they support in the app's supportedLocales list. For example:

import 'l10n/app_localizations.dart';

return MaterialApp(
  localizationsDelegates: AppLocalizations.localizationsDelegates,
  supportedLocales: AppLocalizations.supportedLocales,
  home: MyApplicationHome(),
);

Update pubspec.yaml

Please make sure to update your pubspec.yaml to include the following packages:

dependencies:
  # Internationalization support.
  flutter_localizations:
    sdk: flutter
  intl: any # Use the pinned version from flutter_localizations

  # Rest of dependencies

iOS Applications

iOS applications define key application metadata, including supported locales, in an Info.plist file that is built into the application bundle. To configure the locales supported by your app, you’ll need to edit this file.

First, open your project’s ios/Runner.xcworkspace Xcode workspace file. Then, in the Project Navigator, open the Info.plist file under the Runner project’s Runner folder.

Next, select the Information Property List item, select Add Item from the Editor menu, then select Localizations from the pop-up menu.

Select and expand the newly-created Localizations item then, for each locale your application supports, add a new item and select the locale you wish to add from the pop-up menu in the Value field. This list should be consistent with the languages listed in the AppLocalizations.supportedLocales property.

Implementers

Constructors

AppLocalizations(String locale)

Properties

affiliatePercentMustBeBetween0And90 String
Error for invalid affiliate percentage
no setter
amount String
Label for amount
no setter
amountExceedsLimitForBannedUsers String
Error for amount limits for banned users
no setter
amountExceedsLimitForKycUsers String
Error for amount exceeding KYC user limits
no setter
amountIsRequired String
Error when amount field is missing
no setter
amountMustBeBetween1And999ForNonKyc String
Error for amount limits for non-KYC users
no setter
amountMustBeGreaterThan1ForKyc String
Error for minimum amount for KYC users
no setter
amountMustBeGreaterThanAffiliateAmount String
Error when amount is less than affiliate amount
no setter
amountMustBeValidNumber String
Error when amount is not a valid number
no setter
amountNotFound String
Error when amount data is missing
no setter
banksPayment String
Title for bank payment methods
no setter
callbackSettingNotFound String
Error when callback configuration is missing
no setter
close String
Close button text
no setter
creditCardPaymentNotAllowedForNonKyc String
Error for credit card payment restriction
no setter
creditCards String
Title for credit card payment methods
no setter
description String
Label for description
no setter
descriptionIsRequired String
Error when description field is missing
no setter
descriptionMustNotContainDashCharacter String
Error for dash character in description
no setter
descriptionMustNotContainLaoOrThaiText String
Error for invalid characters in description
no setter
descriptionMustNotExceed25Characters String
Error for description length limit
no setter
done String
Done button text
no setter
error String
General error label
no setter
exchangeNotFound String
Error when exchange rate is not found
no setter
failedToGenerateQrData String
Error when QR code generation fails
no setter
fee String
Label for transaction fee
no setter
Loading message while generating payment link
no setter
generatingQR String
Loading message while generating QR
no setter
hashCode int
The hash code for this object.
no setterinherited
internalServerError String
Internal server error message
no setter
jdbErrorNotSuccess String
JDB bank specific error
no setter
localeName String
final
minimumAmountRequired String
Error message for minimum amount requirement
no setter
minimumRequired String
Short minimum amount message
no setter
noPaymentUrlReceived String
Error message when payment URL is not received
no setter
note String
Note about cross-bank transfers
no setter
openBankApp String
Open bank app button text
no setter
orderNoIsRequired String
Error when orderNo field is missing or invalid
no setter
orScanQR String
Text for QR scan option
no setter
paymentCancelled String
Payment cancellation message
no setter
paymentCompleted String
Payment completion message
no setter
paymentExpired String
Payment expiration message
no setter
paymentLinkNotAvailable String
Error message when payment link is not available
no setter
paymentNotFound String
Error when payment record is not found
no setter
paymentSuccess String
Title for payment success screen
no setter
paymentSuccessful String
Success message
no setter
payWithBankApp String
Text for pay with bank app button
no setter
processingCreditCard String
Loading message for credit card processing
no setter
qrCodeNotGenerated String
Error message when QR code fails to generate
no setter
qrInstructions String
Instructions for QR code usage
no setter
qrPayments String
Title for QR payment methods
no setter
rateLimitExceeded String
Error for daily transaction limit exceeded
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safetyMessage String
Safety assurance message
no setter
saveQR String
Save QR button text
no setter
selectForPayment String
Title for payment selection screen
no setter
totalAmount String
Label for total amount
no setter
transactionId String
Label for transaction ID
no setter
transactionIsExpired String
Error when transaction has expired
no setter
transactionVerified String
Message indicating transaction verification
no setter
tryAgain String
Try again button text
no setter
userNotFound String
Error when user doesn't exist
no setter
waitingForPayment String
Status message while waiting for payment
no setter
wallets String
Title for wallet payment methods
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processingPayment(String bankName) String
Loading message for payment processing
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) AppLocalizations?

Constants

delegate → const LocalizationsDelegate<AppLocalizations>
localizationsDelegates → const List<LocalizationsDelegate>
A list of this localizations delegate along with the default localizations delegates.
supportedLocales → const List<Locale>
A list of this localizations delegate's supported locales.