safetyMessage property

  1. @override
String get safetyMessage
override

Safety assurance message

In en, this message translates to: 'Your safety is our top priority\nRest assured that your payment is secure. Be confident that your information will always be protected.'

Implementation

@override
String get safetyMessage =>
    'Your safety is our top priority\nRest assured that your payment is secure. Be confident that your information will always be protected.';